@@ -276,6 +276,8 @@ show_desktop_applet_fill (PanelApplet *applet)
         char *file;
         GError *error;
 
+	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
+
         sdd = g_new0 (ShowDesktopData, 1);
 
         sdd->applet = GTK_WIDGET (applet);
@@ -326,7 +328,7 @@ show_desktop_applet_fill (PanelApplet *applet)
         g_signal_connect (G_OBJECT (sdd->button), "toggled",
                           G_CALLBACK (button_toggled_callback), sdd);
 
-        gtk_container_set_border_width (GTK_CONTAINER (sdd->button), 1);
+        gtk_container_set_border_width (GTK_CONTAINER (sdd->button), 0);
         gtk_container_add (GTK_CONTAINER (sdd->button), sdd->image);
         gtk_container_add (GTK_CONTAINER (sdd->applet), sdd->button);
 
@@ -387,21 +389,9 @@ display_help_dialog (BonoboUIComponent *uic,
                      const gchar       *verbname)
 {
         GError *error = NULL;
-        static GnomeProgram *applet_program = NULL;
-
-        if (!applet_program) {
-                /* FIXME there is no way this crack is right; it's some junk
-                 * copied from clock.c
-                 */
-                int argc = 1;
-                char *argv[2] = { "show-desktop" };
-                applet_program = gnome_program_init ("show-desktop", VERSION,
-                                                     LIBGNOME_MODULE, argc, argv,
-                                                     GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-        }
 
         egg_help_display_desktop_on_screen (
-                applet_program, "show-desktop", "show-desktop", NULL,
+                NULL, "show-desktop", "show-desktop", NULL,
                 gtk_widget_get_screen (sdd->applet),
 		&error);
 
