@@ -67,6 +67,7 @@ typedef enum {
 
 #define ENABLE_LIST_DEFAULT TRUE
 #define SHOW_LIST_DEFAULT FALSE
+#define IMAGE_SIZE 48.0
 
 static GtkWidget *run_dialog = NULL;
 static GSList *add_icon_paths = NULL;
@@ -583,6 +584,7 @@ browse_ok (GtkWidget *widget, GtkFileSelection *fsel)
 	fname = gtk_file_selection_get_filename (fsel);
 	if (fname != NULL) {
 		append_file (entry, fname);
+		gtk_widget_grab_focus (entry);
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (fsel));
@@ -928,6 +930,7 @@ create_simple_contents (GdkScreen *screen)
         w = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
         pixmap = gtk_image_new ();
 	g_object_set_data (G_OBJECT (run_dialog), "pixmap", pixmap);
+	gtk_widget_set_size_request (pixmap, IMAGE_SIZE + 1, -1);
 	gtk_container_add (GTK_CONTAINER (w), pixmap);
         gtk_box_pack_start (GTK_BOX (hbox), w,
 			    FALSE, FALSE, 10);
@@ -986,7 +989,7 @@ create_simple_contents (GdkScreen *screen)
         gtk_box_pack_start (GTK_BOX (hbox2), w,
                             TRUE, TRUE, 0);
 
-        w = gtk_button_new_with_mnemonic (_("_Append File..."));
+        w = gtk_button_new_with_mnemonic (_("Run with _File..."));
         g_signal_connect(G_OBJECT(w), "clicked",
                          G_CALLBACK (browse), entry);
 	gtk_box_pack_start (GTK_BOX (hbox2), w,
@@ -1455,8 +1458,37 @@ selection_changed (GtkTreeSelection *selection,
 			}
                         
                         if (pixbuf != NULL) {
-				gtk_image_set_from_pixbuf (GTK_IMAGE (gpixmap), pixbuf);
-				g_object_unref (pixbuf);
+				GdkPixbuf *scaled;
+				double     factor;
+				gint       new_w;
+				gint       new_h;
+				gint       w;
+				gint       h;
+
+				w = gdk_pixbuf_get_width (pixbuf);
+				h = gdk_pixbuf_get_height (pixbuf);
+			
+				if (w <= IMAGE_SIZE && h <= IMAGE_SIZE) {
+					
+					gtk_image_set_from_pixbuf (GTK_IMAGE (gpixmap), pixbuf);
+					g_object_unref (pixbuf);
+					
+				} else {
+					
+					factor = MIN (IMAGE_SIZE / w, IMAGE_SIZE / h);
+					new_w  = MAX ((gint) (factor * w), 1);
+					new_h  = MAX ((gint) (factor * h), 1);
+			
+					scaled = gdk_pixbuf_scale_simple (pixbuf,
+						  new_w,
+						  new_h,
+						  GDK_INTERP_BILINEAR);   
+
+					gtk_image_set_from_pixbuf (GTK_IMAGE (gpixmap), scaled);
+					
+					g_object_unref (scaled);
+					g_object_unref (pixbuf);
+				}
                         } else {
                                 unset_pixmap (gpixmap);
                         }
@@ -1521,7 +1553,7 @@ create_program_list_contents (void)
                             TRUE, TRUE, 0);
 
         label = gtk_label_new ("");
-        gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
         gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 5);
         g_object_set_data (G_OBJECT (run_dialog), "desc_label", label);
@@ -1540,40 +1572,53 @@ create_program_list_contents (void)
 static void
 update_contents (GtkWidget *dialog)
 {
-        GtkWidget *program_list_box = NULL;
+	GtkWidget *program_list_box = NULL;
+	GtkWidget *entry;
 
-        if (panel_profile_get_show_program_list ()) {
-                program_list_box = g_object_get_data (G_OBJECT (dialog), "program_list_box");
+	if (panel_profile_get_show_program_list ()) {
+		program_list_box = g_object_get_data (G_OBJECT (dialog), 
+						      "program_list_box");
 
-                if (program_list_box && program_list_box->parent == NULL) {
+		if (program_list_box && program_list_box->parent == NULL) {
 			GtkWidget *list;
-			
+			GtkTreeSelection *selection;
+			GtkTreeModel *model;
+			GtkTreeIter iter;
+
 			gtk_window_resize (GTK_WINDOW (dialog), 100, 300);
 			gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 			
-                        gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-                                            program_list_box,
-                                            TRUE, TRUE, GNOME_PAD_SMALL);
-                
+			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+					    program_list_box,
+					    TRUE, TRUE, GNOME_PAD_SMALL);
 
-                        gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (dialog)->vbox));
+			gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (dialog)->vbox));
 
 			list = g_object_get_data (G_OBJECT (dialog), "program_list");
-			gtk_widget_grab_focus (list);
-		}
-        } else {    
-		GtkWidget *entry;           
+			selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
 
-                program_list_box = g_object_get_data (G_OBJECT (dialog), "program_list_box");
+			if (gtk_tree_view_get_model (GTK_TREE_VIEW (list)) &&
+			    !gtk_tree_selection_get_selected (selection,&model, &iter)) {
+			
+				entry = g_object_get_data (G_OBJECT (dialog), "entry");
+				gtk_widget_grab_focus (entry);
+			} else
+				gtk_widget_grab_focus (list);
+		}
+	} else {    
+
+		program_list_box = g_object_get_data (G_OBJECT (dialog), 
+						      "program_list_box");
                 
-                if (program_list_box && program_list_box->parent != NULL) {
-                        gtk_container_remove (GTK_CONTAINER (program_list_box->parent), program_list_box);
+		if (program_list_box && program_list_box->parent != NULL) {
+			gtk_container_remove (GTK_CONTAINER (program_list_box->parent), 
+					      program_list_box);
 			gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 		}
 
 		entry = g_object_get_data (G_OBJECT (dialog), "entry");
-                gtk_widget_grab_focus (entry);
-        }
+		gtk_widget_grab_focus (entry);
+	}
 }
 
 static void
@@ -1616,7 +1661,7 @@ show_run_dialog (GdkScreen *screen)
 	}
 
 	run_dialog = gtk_dialog_new_with_buttons (
-				_("Run Program"),
+				_("Run Application"),
 				NULL, 0 /* flags */,
 				GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1661,11 +1706,13 @@ show_run_dialog (GdkScreen *screen)
 			g_idle_add_full (G_PRIORITY_LOW, add_items_idle,
 			 		 w, NULL);
 
-		gtk_widget_grab_focus (w);
-	} else {
-		w = g_object_get_data (G_OBJECT (run_dialog), "entry");
-		gtk_widget_grab_focus (w);
-	}
+	} 
+
+	/* None of the apps in the list are selected when the dialog is launched.
+	   Hence entry can be safely grabbed
+	*/
+	w = g_object_get_data (G_OBJECT (run_dialog), "entry");
+	gtk_widget_grab_focus (w);
 	
 	gtk_widget_show_all (run_dialog);
 }
