@@ -1,22 +1,22 @@
 /*
- * panel-stock-icons.c
+ * panel-stock-icons.c panel stock icons registration
  *
  * Copyright (C) 2002 Sun Microsystems, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  *
  * Authors:
  *	Mark McLoughlin <mark@skynet.ie>
@@ -31,10 +31,11 @@
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-desktop-item.h>
 
-#include "panel-main.h"
+#include "panel-globals.h"
 
 static GtkIconSize panel_menu_icon_size = 0;
-static GtkIconSize panel_foobar_icon_size = 0;
+static GtkIconSize panel_menu_bar_icon_size = 0;
+static GtkIconSize panel_button_icon_size = 0;
 
 GtkIconSize
 panel_menu_icon_get_size (void)
@@ -43,9 +44,15 @@ panel_menu_icon_get_size (void)
 }
 
 GtkIconSize
-panel_foobar_icon_get_size (void)
+panel_menu_bar_icon_get_size (void)
 {
-	return panel_foobar_icon_size;
+	return panel_menu_bar_icon_size;
+}
+
+GtkIconSize
+panel_button_icon_get_size (void)
+{
+	return panel_button_icon_size;
 }
 
 typedef struct {
@@ -74,10 +81,15 @@ static PanelStockIcon stock_icons [] = {
 	{ PANEL_STOCK_SLIDING_PANEL,       "gnome-panel-type-sliding" },
 	{ PANEL_STOCK_MENU_PANEL,          "gnome-panel-type-menu" },
 	{ PANEL_STOCK_LAUNCHER,            "launcher-program" },
+	{ PANEL_STOCK_ACTION,		   NULL },
 	{ PANEL_STOCK_DRAWER,              "panel-drawer" },
 	{ PANEL_STOCK_APPLETS,             "gnome-applets" },
 	{ PANEL_STOCK_DESKTOP,             "gnome-ccdesktop" },
 	{ PANEL_STOCK_KDE,                 "go" },
+	{ PANEL_STOCK_ARROW_RIGHT,         "panel-arrow-right" },
+	{ PANEL_STOCK_ARROW_LEFT,          "panel-arrow-left" },
+	{ PANEL_STOCK_ARROW_UP,            "panel-arrow-up" },
+	{ PANEL_STOCK_ARROW_DOWN,          "panel-arrow-down" },
 };
 
 static void
@@ -96,6 +108,9 @@ panel_init_stock_icons (GtkIconFactory *factory)
 		GtkIconSet *set;
 		char       *filename;
 
+		if (!stock_icons [i].icon)
+			continue;
+
 		filename = gnome_desktop_item_find_icon (
 				panel_icon_theme, stock_icons [i].icon, icon_height, 0);
 		if (!filename) {
@@ -165,7 +180,11 @@ panel_init_stock_icons_and_items (void)
 						       PANEL_DEFAULT_MENU_ICON_SIZE,
 						       PANEL_DEFAULT_MENU_ICON_SIZE);
 
-	panel_foobar_icon_size = gtk_icon_size_register ("panel-foobar", 20, 20);
+	panel_menu_bar_icon_size = gtk_icon_size_register ("panel-foobar", 20, 20);
+
+	panel_button_icon_size = gtk_icon_size_register ("panel-button",
+							 PANEL_DEFAULT_BUTTON_ICON_SIZE,
+							 PANEL_DEFAULT_BUTTON_ICON_SIZE);
 
 	factory = gtk_icon_factory_new ();
 	gtk_icon_factory_add_default (factory);
