@@ -32,24 +32,17 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include <libwnck/screen.h>
-#include <libwnck/workspace.h>
-
 #include "panel-util.h"
 
 #include "applet.h"
 #include "nothing.h"
-#include "basep-widget.h"
-#include "foobar-widget.h"
 #include "panel.h"
+#include "panel-a11y.h"
 #include "egg-screen-exec.h"
 #include "egg-screen-url.h"
 #include "egg-screen-help.h"
-
-extern GlobalConfig global_config;
-
-extern GSList *applets;
-extern GSList *panels;
+#include "xstuff.h"
+#include "panel-globals.h"
 
 GdkScreen *
 panel_screen_from_number (int screen)
@@ -65,18 +58,9 @@ panel_ditem_launch (const GnomeDesktopItem       *item,
 		    GdkScreen                    *screen,
 		    GError                      **error)
 {
-	WnckScreen *wnck_screen = NULL;
-	int         workspace;
+	int workspace;
 
-	if (screen)
-		wnck_screen = wnck_screen_get (
-				gdk_screen_get_number (screen));
-
-	if (!wnck_screen)
-		wnck_screen = wnck_screen_get_default ();
-
-	workspace = wnck_workspace_get_number (
-			wnck_screen_get_active_workspace (wnck_screen));
+	workspace = xstuff_get_current_workspace (screen);
 
 	return gnome_desktop_item_launch_on_screen (
 			item, file_list, flags, screen, workspace, error);
@@ -251,7 +235,7 @@ create_text_entry(GtkWidget *table,
 			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
 			 GTK_FILL | GTK_SHRINK,
 			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
-	panel_set_atk_relation (entry, GTK_LABEL (wlabel));
+	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
 
 	if(func) {
 		g_object_set_data (G_OBJECT (t), "update_function", func);
@@ -290,7 +274,7 @@ create_icon_entry(GtkWidget *table,
 	if (text != NULL)
 		gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(entry), text);
 
-	panel_set_atk_relation (entry, GTK_LABEL (wlabel));
+	panel_a11y_set_atk_relation (entry, GTK_LABEL (wlabel));
 	gtk_table_attach(GTK_TABLE(table), entry,
 			 cols, cole, 1, 2,
 			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
@@ -571,6 +555,15 @@ set_color_back (GtkWidget *widget, PanelWidget *panel)
 	GdkColor  gdkcolor = {0, };
 	int       i;
 
+	/* FIXME:
+	 *   need to implement alpha background for these
+	 *   widgets too ...
+	 */
+	if (panel->background.has_alpha) {
+		gtk_widget_set_style (widget, NULL);
+		return;
+	}
+
 	gdkcolor = panel->background.color.gdk;
 
 	gtk_widget_set_style (widget, NULL);
@@ -616,38 +609,6 @@ panel_set_frame_colors (PanelWidget *panel, GtkWidget *frame,
 	}
 }
 
-gboolean
-panel_parse_accelerator (GlobalConfigKey *key)
-{
-	g_return_val_if_fail (key != NULL, FALSE);
-	
-	key->keysym = 0;
-	key->state = 0;
-
-	if (key->str == NULL ||
-	    key->str[0] == '\0' ||
-	    strcmp (key->str, "Disabled") == 0 ||
-	    strcmp (key->str, _("Disabled")) == 0)
-		return FALSE;
-
-	gtk_accelerator_parse (key->str, &key->keysym, &key->state);
-
-	if (key->keysym == 0)
-		return FALSE;
-
-	return TRUE;
-}
-
-char *
-convert_keysym_state_to_string(guint keysym,
-			       GdkModifierType state)
-{
-	if (keysym == 0)
-		return g_strdup (_("Disabled"));
-
-	return gtk_accelerator_name (keysym, state);
-}
-
 static GtkWidget *
 panel_dialog (GdkScreen  *screen,
 	      int         type,
@@ -764,13 +725,15 @@ is_ext2 (const char *file,
 }
 
 int
-panel_find_applet (GtkWidget *widget)
+panel_find_applet_index (GtkWidget *widget)
 {
-	int i;
-	GSList *li;
+	GSList *applet_list, *l;
+	int     i;
 
-	for (i = 0, li = applets; li != NULL; i++, li = li->next) {
-		AppletInfo *info = li->data;
+	applet_list = panel_applet_list_applets ();
+
+	for (i = 0, l = applet_list; l; i++, l = l->next) {
+		AppletInfo *info = l->data;
 
 		if (info->widget == widget)
 			return i;
