@@ -2,6 +2,9 @@
 #define PANEL_UTIL_H
 
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
+
+#include <libgnome/gnome-desktop-item.h>
 
 #include "panel-widget.h"
 #include "panel-config-global.h"
@@ -40,7 +43,17 @@ GtkWidget *	create_icon_entry	(GtkWidget *table,
 					 UpdateFunction func,
 					 gpointer data);
 
-void		panel_show_help		(const char *path,
+int             panel_ditem_launch         (const GnomeDesktopItem       *item,
+					    GList                        *file_list,
+					    GnomeDesktopItemLaunchFlags   flags,
+					    GdkScreen                    *screen,
+					    GError                      **error);
+GdkScreen      *panel_screen_from_number   (int           screen);
+
+
+
+void		panel_show_help		(GdkScreen  *screen,
+					 const char *path,
 					 const char *linkid);
 
 GList *		panel_g_list_swap_next	(GList *list,
@@ -63,25 +76,14 @@ void		panel_set_frame_colors	(PanelWidget *panel,
 					 GtkWidget *but3,
 					 GtkWidget *but4);
 
-gboolean        panel_parse_accelerator (GlobalConfigKey *key);
-
-char *		convert_keysym_state_to_string (guint keysym,
-						GdkModifierType state);
-
-GtkWidget *	panel_error_dialog	(const char *class,
+GtkWidget      *panel_error_dialog      (GdkScreen  *screen,
+					 const char *class,
 					 const char *format,
-					 ...) G_GNUC_PRINTF (2, 3);
-GtkWidget *	panel_info_dialog	(const char *class,
+					 ...) G_GNUC_PRINTF (3, 4);
+GtkWidget      *panel_info_dialog       (GdkScreen  *screen,
+					 const char *class,
 					 const char *format,
-					 ...) G_GNUC_PRINTF (2, 3);
-GtkWidget *	panel_error_dialog_with_parent (GtkWindow *parent,
-						const char *class,
-						const char *format,
-						...) G_GNUC_PRINTF (3, 4);
-GtkWidget *	panel_info_dialog_with_parent (GtkWindow *parent,
-					       const char *class,
-					       const char *format,
-					       ...) G_GNUC_PRINTF (3, 4);
+					 ...) G_GNUC_PRINTF (3, 4);
 
 gboolean	is_ext			(const char *file,
 					 const char *ext);
@@ -89,7 +91,7 @@ gboolean	is_ext2			(const char *file,
 					 const char *ext1,
 					 const char *ext2);
 
-int		panel_find_applet	(GtkWidget *widget);
+int		panel_find_applet_index	(GtkWidget *widget);
 
 int		get_requisition_width	(GtkWidget *widget);
 int		get_requisition_height	(GtkWidget *widget);
@@ -102,8 +104,9 @@ typedef enum {
 #define PANEL_HELP_ERROR panel_help_error_quark ()
 GQuark panel_help_error_quark (void);
 
-gboolean	panel_show_gnome_kde_help (const char *docpath,
-					   GError **error);
+gboolean	panel_show_gnome_kde_help (GdkScreen   *screen,
+					   const char  *docpath,
+					   GError     **error);
 
 gboolean	panel_is_url		(const char *url);
 
@@ -118,21 +121,24 @@ char *		panel_pixmap_discovery	(const char *name,
 void		panel_stretch_events_to_toplevel (GtkWidget         *widget,
 						  PanelStretchFlags  flags);
 
-void		panel_signal_connect_while_alive (GObject     *object,
-						  const gchar *signal,
-						  GCallback    func,
-						  gpointer     func_data,
-						  GObject     *alive_object);
-void		panel_signal_connect_object_while_alive (GObject      *object,
-							 const gchar  *signal,
-							 GCallback     func,
-							 GObject      *alive_object);
+void		panel_signal_connect_while_alive        (gpointer     object,
+							 const gchar *signal,
+							 GCallback    func,
+							 gpointer     func_data,
+							 gpointer     alive_object);
+void		panel_signal_connect_object_while_alive (gpointer     object,
+							 const gchar *signal,
+							 GCallback    func,
+							 gpointer     alive_object);
 
 gboolean	panel_ensure_dir	(const char *dirname);
 
 gboolean	panel_is_uri_writable	(const char *uri);
 gboolean	panel_uri_exists	(const char *uri);
 
+void            panel_lock_screen       (GdkScreen *screen);
+
+
 /* GnomeVFS reading utils */
 
 typedef struct _ReadBuf ReadBuf;
@@ -148,10 +154,13 @@ gboolean	readbuf_rewind		(ReadBuf *rb);
 void		readbuf_close		(ReadBuf *rb);
 
 /* Accessibility support routines */
-void add_atk_name_desc (GtkWidget *widget, gchar *name, gchar *desc);
-void set_relation (GtkWidget *widget, GtkLabel *label, int set_for);
+void panel_set_atk_name_desc (GtkWidget *widget,
+			      char      *name,
+			      char      *desc);
+void panel_set_atk_relation  (GtkWidget *widget,
+			      GtkLabel  *label);
 
-/* FIXME : make battery stuff public as appropriate */
+GdkPixbuf *	missing_pixbuf		(int size);
 
 
 G_END_DECLS
